@@ -5,18 +5,18 @@
 ### code chunk number 1: credibility.Rnw:76-78
 ###################################################
 library(actuar)
-options(width = 52, digits = 4)
+options(width = 57, digits = 4)
 
 
 ###################################################
-### code chunk number 2: credibility.Rnw:113-115
+### code chunk number 2: credibility.Rnw:114-116
 ###################################################
 data(hachemeister)
 hachemeister
 
 
 ###################################################
-### code chunk number 3: credibility.Rnw:269-275
+### code chunk number 3: credibility.Rnw:270-276
 ###################################################
 X <- cbind(cohort = c(1, 2, 1, 2, 2), hachemeister)
 fit <- cm(~cohort + cohort:state, data = X,
@@ -27,13 +27,13 @@ fit
 
 
 ###################################################
-### code chunk number 4: credibility.Rnw:282-283
+### code chunk number 4: credibility.Rnw:283-284
 ###################################################
 predict(fit)
 
 
 ###################################################
-### code chunk number 5: credibility.Rnw:288-289
+### code chunk number 5: credibility.Rnw:289-290
 ###################################################
 summary(fit)
 
@@ -46,20 +46,20 @@ predict(fit, levels = "cohort")
 
 
 ###################################################
-### code chunk number 7: credibility.Rnw:329-330
+### code chunk number 7: credibility.Rnw:325-326
 ###################################################
 cm(~state, hachemeister, ratios = ratio.1:ratio.12)
 
 
 ###################################################
-### code chunk number 8: credibility.Rnw:335-337
+### code chunk number 8: credibility.Rnw:333-335
 ###################################################
 cm(~state, hachemeister, ratios = ratio.1:ratio.12,
    weights = weight.1:weight.12)
 
 
 ###################################################
-### code chunk number 9: credibility.Rnw:366-371
+### code chunk number 9: credibility.Rnw:364-369
 ###################################################
 fit <- cm(~state, hachemeister, regformula = ~ time,
           regdata = data.frame(time = 1:12),
@@ -69,13 +69,13 @@ fit
 
 
 ###################################################
-### code chunk number 10: credibility.Rnw:376-377
+### code chunk number 10: credibility.Rnw:374-375
 ###################################################
 predict(fit, newdata = data.frame(time = 13))
 
 
 ###################################################
-### code chunk number 11: credibility.Rnw:387-400
+### code chunk number 11: credibility.Rnw:385-398
 ###################################################
 plot(NA, xlim = c(1, 13), ylim = c(1000, 2000), xlab = "", ylab = "")
 x <- cbind(1, 1:12)
@@ -93,7 +93,7 @@ legend("bottomright",
 
 
 ###################################################
-### code chunk number 12: credibility.Rnw:417-423
+### code chunk number 12: credibility.Rnw:415-421
 ###################################################
 fit2 <- cm(~state, hachemeister, regformula = ~ time,
            regdata = data.frame(time = 1:12),
@@ -104,7 +104,7 @@ summary(fit2, newdata = data.frame(time = 13))
 
 
 ###################################################
-### code chunk number 13: credibility.Rnw:430-444
+### code chunk number 13: credibility.Rnw:428-442
 ###################################################
 plot(NA, xlim = c(1, 13), ylim = c(1000, 2000), xlab = "", ylab = "")
 x <- cbind(1, 1:12)
@@ -122,3 +122,13 @@ legend("bottomright",
        col = c("blue", "red", "darkgreen"), lty = 1:3)
 
 
+###################################################
+### code chunk number 14: credibility.Rnw:569-574
+###################################################
+x <- c(5, 3, 0, 1, 1)
+fit <- cm("bayes", x, likelihood = "poisson",
+           shape = 3, rate = 3)
+fit
+predict(fit)
+
+
